OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Contactados recentemente",
    "Contacts Interaction" : "Interação de contatos",
    "Manages interaction between users and contacts" : "Gerenciar interação entre usuários e contatos",
    "Collect data about user and contacts interactions and provide an address book for the data" : "Coletar dados sobre usuários e interação de contatos e prover um livro de endereços para o dado"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
